import OpenLogin from "@toruslabs/openlogin";
import { LoginParams, OpenLoginOptions } from "@toruslabs/openlogin-utils";
import { ADAPTER_CATEGORY_TYPE, ADAPTER_STATUS_TYPE, AdapterInitOptions, AdapterNamespaceType, BaseAdapter, BaseAdapterSettings, ChainNamespaceType, CustomChainConfig, IProvider, UserInfo } from "@web3auth/base";
import type { OpenloginAdapterOptions, PrivateKeyProvider } from "./interface";
export type OpenloginLoginParams = LoginParams & {
    login_hint?: string;
};
export declare class OpenloginAdapter extends BaseAdapter<OpenloginLoginParams> {
    readonly name: string;
    readonly adapterNamespace: AdapterNamespaceType;
    readonly type: ADAPTER_CATEGORY_TYPE;
    openloginInstance: OpenLogin | null;
    status: ADAPTER_STATUS_TYPE;
    currentChainNamespace: ChainNamespaceType;
    privateKeyProvider: PrivateKeyProvider | null;
    private openloginOptions;
    private loginSettings;
    constructor(params?: OpenloginAdapterOptions);
    get chainConfigProxy(): CustomChainConfig | null;
    get provider(): IProvider | null;
    set provider(_: IProvider | null);
    init(options: AdapterInitOptions): Promise<void>;
    connect(params?: OpenloginLoginParams): Promise<IProvider | null>;
    enableMFA(params?: OpenloginLoginParams): Promise<void>;
    disconnect(options?: {
        cleanup: boolean;
    }): Promise<void>;
    authenticateUser(): Promise<{
        idToken: string;
    }>;
    getUserInfo(): Promise<Partial<UserInfo>>;
    setAdapterSettings(adapterSettings: Partial<OpenLoginOptions & BaseAdapterSettings> & {
        privateKeyProvider?: PrivateKeyProvider;
    }): void;
    addChain(chainConfig: CustomChainConfig, init?: boolean): Promise<void>;
    switchChain(params: {
        chainId: string;
    }, init?: boolean): Promise<void>;
    private _getFinalPrivKey;
    private _getFinalEd25519PrivKey;
    private connectWithProvider;
}
